{% extends "customer/emails/base.html" %}
{% load currency_filters i18n %}

{% block tbody %}
<tr>
    <td class="content-block">
        <p xmlns="http://www.w3.org/1999/html">{% trans 'Hello' %} {{ user.get_full_name }},</p>
        <p style="white-space: pre;">{% blocktrans with order_number=order.number %}We are pleased to confirm your order {{ order_number }} has been shipped.{% endblocktrans %}</p>
    </td>
</tr>

<tr>
    <td class="content-block">
        <table class="order">
            <tbody><tr>
                <th>{% trans 'Your shipment contains' %}:</th>
            </tr>
            <tr>
                <td>
                    <table class="order-items" cellpadding="0" cellspacing="0">
                        <tbody>
                            {% for line, quantity in lines %}
                                <tr>
                                    <td>{{ line.title }}</td>
                                    <td class="alignright">&times; {{ quantity }}</td>
                                </tr>
                            {% endfor %}
                        </tbody>
                    </table>
                </td>
            </tr>
        </tbody></table>
    </td>
</tr>

<tr>
    <th class="alignleft">{% trans 'Shipping address:' %}</th>
</tr>
<tr>
    <td class="content-block">
        <p>{% for field in order.shipping_address.ordered_active_address_fields %}  {{ field }}<br/>
        {% endfor %}</p>
    </td>
</tr>

{% if tracking_url %}
    <tr>
        <td class="content-block">
            {% blocktrans %}You can view the status of your shipment by clicking <a href="{{ tracking_url }}" title="order status">here</a>{% endblocktrans %}
            {% if tracking.tracking_code %}
               {% blocktrans %}Your tracking code is: {{tracking.tracking_code}}{% endblocktrans %}
            {% endif %}
        </td>
    </tr>
{% endif %}

{% endblock %}
