# pylint: disable=no-name-in-module
from oscar.apps.communication import apps as oscar


class CommunicationConfig(oscar.CommunicationConfig):
    name = "ocyan.plugin.oscar_communications.communication"
