# -*- coding: utf-8 -*-
default_app_config = (
    "ocyan.plugin.oscar_communications.apps.OcyanPluginOscarCommunicationsAppConfig"
)
from ocyan.plugin.oscar.info import OSCAR_NEEDS_OXYAN

if OSCAR_NEEDS_OXYAN:
    from .entrypoint import Oscar3CommunicationsConfig  # noqa
else:
    from .entrypoint import OscarCommunicationsConfig  # noqa
