{% extends "customer/emails/base.html" %}
{% load i18n ocyan_main %}

{% block tbody %}
<tr>
    <td class="content-block">
        <p>
            {% with user=alert.user %}{% trans 'Hello' %} {{ user.get_full_name }},{% endwith %}
        </p>
    </td>
</tr>
<tr>
    <td class="content-block">
        <p>
        {% blocktrans with title=alert.product.get_title|safe %}Somebody (hopefully you) has requested an email alert when '{{ title }}' is back in stock.{% endblocktrans %}<br/>
        {% trans 'Please click the following link to confirm' %}:
        </p>
    </td>
</tr>
<tr>
    <td class="content-block"><a href="{% absolute_url alert.get_confirm_url %}" class="btn-primary">{% trans 'Confirm' %}</a></td>
</tr>
<tr>
    <td class="content-block">
        <p>
            {% trans 'You can cancel this alert at any time by clicking the following link' %}:
        </p>
    </td>
</tr>
<tr>
    <td class="content-block"><a href="{% absolute_url alert.get_cancel_url %}" class="btn-secondary">{% trans 'Cancel' %}</a></td>
</tr>
{% endblock %}
