{% load i18n wagtailimages_tags wagtailsettings_tags compress static ocyan_main %}
{% get_settings %}<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
    <head>
        <meta name="viewport" content="width=device-width" />
        <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
        {% compress css inline %}
            <link rel="stylesheet" type="text/x-scss" href="{% static 'communications/email.scss' %}">
        {% endcompress %}
    </head>

    <body id="email-body" itemscope itemtype="http://schema.org/EmailMessage">

    <table class="body-wrap">
        <tr>
            <td></td>
            <td class="container" width="600">
                <div class="content">
                    
                    <table class="main" width="100%" cellpadding="0" cellspacing="0" itemprop="action" itemscope itemtype="http://schema.org/ConfirmAction">
                        <tr>
                            <td class="content-wrap">
                                <table width="100%" cellpadding="0" cellspacing="0">
                                    {% block header %}
                                    <tr>
                                        <td class="alignright logo">
                                            <a href="{% absolute_url '/' %}">
                                                {% image settings.ocyan_plugin_wagtail.OcyanSettings.logo height-40 as logo %}
                                                <img alt="{{ site.name }}" height="{{ logo.height }}" src="{% absolute_url logo.url %}" width="{{ logo.width }}">
                                            </a>
                                        </td>
                                    </tr>
                                    {% endblock %}
                                    {% block tbody %}
                                    <tr>
                                        <td class="content-block">
                                            {% block body %}{% endblock %}
                                        </td>
                                    </tr>
                                    {% endblock %}
                                    {% block footer %}
                                        <tr>
                                            <td class="content-block">
                                                <p>{% trans "Thank you for using our site!" %}</p>
                                                <p>{% absolute_url '/' as site_url %}{% blocktrans with name=site.name %}The <a href="{{ site_url }}">{{ name }}</a> team{% endblocktrans %}</p>
                                            </td>
                                        </tr>
                                    {% endblock %}
                                </table>
                            </td>
                        </tr>
                    </table>
                </div>
            </td>
            <td></td>
        </tr>
    </table>

    </body>
</html>