{% extends "customer/emails/base.html" %}
{% load i18n ocyan_main %}

{% block tbody %}
<tr>
    <td class="content-block">
        <p xmlns="http://www.w3.org/1999/html">{% trans 'Hello' %} {{ user.get_full_name }},</p>
        <p>{% blocktrans with name=site.name %}You're receiving this e-mail because you requested a password reset for your user account at {{ name }}.{% endblocktrans %}</p>
    </td>
</tr>

<tr>
    <td class="content-block">
        {% trans "Please go to the following page and choose a new password:" %}
    </td>
</tr>

<tr>
    <td class="content-block">
        <a href="{% absolute_url reset_url %}" class="btn-primary">{% trans 'Reset password' %}</a>
    </td>
</tr>

{% endblock %}
