"""
The code in this file is there to ensure that the original migrations
of the app are loaded into the new migration module.

This ensures that you don't have to copy all migrations
when you modify your migration module to adjust/override a (abstract) model.

The migration loader uses pkgutil for migration dicovery.
That allows us to use pkgutil.extend_path to add the existing migrations.

A plugin extension can include migrations by registering a new migration module using settings.MIGRATION_MODULES,
you should use this to register the new migration module path containing the customizations.
It might be that this is allready in place by an extension or an override.
Please check if this is the case before writing you import by running `manage.py settings MIGRATION_MODULES`.
"""

import pkgutil
from oscar.apps.communication import migrations

__path__ = pkgutil.extend_path(__path__, migrations.__name__)
