$primary: ocyancolor("primary_color");
$secondary: ocyancolor("secondary_color");
$info: ocyancolor("info_color");
$success: ocyancolor("success_color");
$danger: ocyancolor("danger_color");
$warning: ocyancolor("warning_color");
$lightgray: #f6f6f6;

* {
  margin: 0;
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  box-sizing: border-box;
  font-size: 14px;
}

img {
  max-width: 100%;
}

/* Outlooks replaces body with div, so the fix is adding a ID to the body and apply styling there. */
#email-body {
  -webkit-font-smoothing: antialiased;
  -webkit-text-size-adjust: none;
  width: 100% !important;
  height: 100%;
  line-height: 1.6em;
}

table {
    td {
      vertical-align: top;
      &.logo {
          padding-bottom: 10px;
      }
    }
    th {
        color: $primary;
    }
}

body {
  background-color: $lightgray;
}

.body-wrap {
  background-color: $lightgray;
  width: 100%;
}

.container {
  display: block !important;
  max-width: 600px !important;
  margin: 0 auto !important;
  clear: both !important;
}

.content {
  max-width: 600px;
  margin: 0 auto;
  display: block;
  padding: 20px;
}

.main {
  background-color: #fff;
  border: 1px solid #e9e9e9;
  border-radius: 3px;
}

.content-wrap {
  padding: 20px;
}

.content-block {
  padding: 0 0 20px;
}

.header {
  width: 100%;
  margin-bottom: 20px;
}

.footer {
  width: 100%;
  clear: both;
  color: #999;
  padding: 20px;
}
.footer p, .footer a, .footer td {
  color: #999;
  font-size: 12px;
}

h1, h2, h3 {
  font-family: "Helvetica Neue", Helvetica, Arial, "Lucida Grande", sans-serif;
  color: $primary;
  margin: 40px 0 0;
  line-height: 1.2em;
  font-weight: 400;
}

h1 {
  font-size: 32px;
  font-weight: 500;
}

h2 {
  font-size: 24px;
}

h3 {
  font-size: 18px;
}

h4 {
  font-size: 14px;
  font-weight: 600;
}
small {
    display: inline;
    font-weight: 400;
    font-size: 12px;
    line-height: 20px;
    padding-right: 20px;
}
p, ul, ol {
  margin-bottom: 10px;
  font-weight: normal;
}
p li, ul li, ol li {
  margin-left: 5px;
  list-style-position: inside;
}

a {
  color: $primary;
  text-decoration: underline;
}

.btn-primary {
  text-decoration: none;
  color: #FFF;
  background-color: $primary;
  border: solid $primary;
  border-width: 10px 20px;
  line-height: 2em;
  font-weight: bold;
  text-align: center;
  cursor: pointer;
  display: inline-block;
  border-radius: 5px;
  text-transform: capitalize;
}

.btn-secondary {
  @extend .btn-primary;
  background-color: $warning;
  border: solid $warning;
  border-width: 10px 20px;
}

.last {
  margin-bottom: 0;
}

.first {
  margin-top: 0;
}

.aligncenter {
  text-align: center;
}

.alignright {
  text-align: right;
}

.alignleft {
  text-align: left;
}

.clear {
  clear: both;
}

.alert {
  font-size: 16px;
  color: #fff;
  font-weight: 500;
  padding: 20px;
  text-align: center;
  border-radius: 3px 3px 0 0;
}
.alert a {
  color: #fff;
  text-decoration: none;
  font-weight: 500;
  font-size: 16px;
}
.alert.alert-warning {
  background-color: #FF9F00;
}
.alert.alert-bad {
  background-color: #D0021B;
}
.alert.alert-good {
  background-color: #68B90F;
}

.invoice {
  margin: 40px auto;
  text-align: left;
  width: 80%;
}
.order {
  text-align: left;
  width: 100%;
}

.invoice, .order {
    td {
      padding: 5px 0;
    }

    .invoice-items, .order-items {
        width: 100%;

        td {
          border-top: $lightgray 1px solid;
          ul {
              list-style-position: inside;
              padding-left: 10px;
          }
        }
        tr {
            &.no-border {
                td {
                    border-top: none;
                }
            }
            &.subtotal, &.discount {
                td {
                    padding: 5px 10px;
                }
            }
            &.total {
                td {
                    border-top: 2px solid $primary;
                    border-bottom: 2px solid $primary;
                    font-weight: 700;
                    &.total {
                        font-size: 16px;
                    }
                }
            }
        }
    }
}

@media only screen and (max-width: 640px) {
  body {
    padding: 0 !important;
  }

  h1, h2, h3, h4 {
    font-weight: 800 !important;
    margin: 20px 0 5px !important;
  }

  h1 {
    font-size: 22px !important;
  }

  h2 {
    font-size: 18px !important;
  }

  h3 {
    font-size: 16px !important;
  }

  .container {
    padding: 0 !important;
    width: 100% !important;
  }

  .content {
    padding: 0 !important;
  }

  .content-wrap {
    padding: 10px !important;
  }

  .invoice {
    width: 100% !important;
  }

  .order {
    width: 100% !important;
  }
}
