from django.urls import path

from .constants import APP_LABEL
from .views import OrderEmailPreview, UserEmailPreview

app_name = APP_LABEL
urlpatterns = [
    path(
        "order-email/<str:slug>/<str:event_type>/",
        OrderEmailPreview.as_view(),
        kwargs={"extension": "html"},
    ),
    path(
        "order-email/<str:slug>/<str:event_type>.<str:extension>",
        OrderEmailPreview.as_view(),
        name="order-email-detail",
    ),
    path(
        "user-email/<str:slug>/<str:event_type>/",
        UserEmailPreview.as_view(),
        kwargs={"extension": "html"},
    ),
    path(
        "user-email/<str:slug>/<str:event_type>.<str:extension>",
        UserEmailPreview.as_view(),
        name="user-email-detail",
    ),
]
