{% extends "customer/emails/base.html" %}
{% load i18n ocyan_main %}

{% block tbody %}
<tr>
    <td class="content-block">
        <p>
            {% with user=alert.user %}{% trans 'Hello' %} {{ user.get_full_name }},{% endwith %}
        </p>
    </td>
</tr>
<tr>
    <td class="content-block">
        <p>
        {% blocktrans with title=alert.product.get_title|safe %}We are happy to inform you that our product '{{ title }}' is back in stock{% endblocktrans %}!
        </p>
    </td>
</tr>
<tr>
    <td class="content-block"><a href="{% absolute_url alert.product.get_absolute_url %}" class="btn-primary">{% trans 'View on site' %}</a></td>
</tr>
{% if hurry %}
<tr>
    <td class="content-block">
        <p>
            {% trans 'Beware that the amount of items in stock is limited. Be quick or someone might get there first.' %}
        </p>
    </td>
</tr>
{% endif %}
<tr>
    <td class="content-block">
        <p>{# do not change the indent of the below text or the translation is lost #}
{% blocktrans %}
With this email we have disabled your alert automatically and you will not
receive any further email regarding this product.
{% endblocktrans %}
        </p>
    </td>
</tr>
{% endblock %}
