{% extends "customer/emails/base.html" %}
{% load i18n %}

{% block tbody %}
<tr>
    <td class="content-block">
        <p xmlns="http://www.w3.org/1999/html">{% trans 'Thank you for registering.' %}</p>
    </td>
</tr>
{% endblock %}
